Enum html_streaming_editor::Command
source · [−]pub enum Command<'a> {
Only(CssSelectorList<'a>),
Filter(CssSelectorList<'a>),
}Variants
Only(CssSelectorList<'a>)
Find all nodes, beginning at the input, that match the given CSS selector and return only those
Filter(CssSelectorList<'a>)
Find all nodes, beginning at the input, that match the given CSS selector and remove them from their parent nodes. Returns the input as result.